Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(68)

Unified Diff: vboot_firmware/include/load_firmware_fw.h

Issue 2743004: Add dummy implementation of LoadFirmware(); currently a wrapper around the old implementation. (Closed) Base URL: ssh://gitrw.chromium.org/vboot_reference.git
Patch Set: rename member Created 10 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « vboot_firmware/Makefile ('k') | vboot_firmware/lib/load_firmware_fw.c » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: vboot_firmware/include/load_firmware_fw.h
diff --git a/vboot_firmware/include/load_firmware_fw.h b/vboot_firmware/include/load_firmware_fw.h
index 47f2ec607201393696b426f98055990edb4e656e..58dd6da55fe1bccdaa31226c2f8349f27efdbc42 100644
--- a/vboot_firmware/include/load_firmware_fw.h
+++ b/vboot_firmware/include/load_firmware_fw.h
@@ -13,43 +13,43 @@
/* Functions provided by PEI to LoadFirmware() */
/* Get the firmware data for [firmware_index], which is either
* 0 (the first firmware image) or 1 (the second firmware image).
*
* This function must call LoadFirmwareUpdateDataHash() before
* returning, to update the secure hash for the firmware image. For
* best performance, the reader should call this function periodically
* during the read, so that updating the hash can be pipelined with
* the read. If the reader cannot update the hash during the read
- * process, it should call LoadFirmwareUpdateDataHash() on the entire
+ * process, it should call UpdateFirmwareBodyHash() on the entire
* firmeware data after the read, before returning.
*
* On success, returns a pointer to the data and stores the data size
* in [*size]. On error, returns NULL. */
-void *FirmwareImageGetData(uint64_t firmware_index, uint64_t* size);
+void *GetFirmwareBody(uint64_t firmware_index, uint64_t* size);
/* Interface provided by verified boot library to PEI */
/* Return codes for LoadFirmware() */
-#define LOAD_FIRMWARE_SUCCESS 0
-#define LOAD_FIRMWARE_RECOVERY 1
+#define LOAD_FIRMWARE_SUCCESS 0 /* Success */
+#define LOAD_FIRMWARE_RECOVERY 1 /* Reboot to recovery mode */
/* Update the data hash for the current firmware image, extending it
* by [size] bytes stored in [*data]. This function must only be
- * called inside FirmwareImageGetData(). */
-void LoadFirmwareUpdateDataHash(uint8_t* data, uint64_t size);
+ * called inside GetFirmwareBody(). */
+void UpdateFirmwareBodyHash(uint8_t* data, uint64_t size);
typedef struct LoadFirmwareParams {
/* Inputs to LoadFirmware() */
- void *header_sign_key_blob; /* Key used to sign firmware header */
- void *vblock0; /* Key block + preamble for firmware 0 */
- void *vblock1; /* Key block + preamble for firmware 1 */
+ void *firmware_root_key_blob; /* Key used to sign firmware header */
+ void *verification_block_0; /* Key block + preamble for firmware 0 */
+ void *verification_block_1; /* Key block + preamble for firmware 1 */
/* Outputs from LoadFirmware(); valid only if LoadFirmware() returns
* LOAD_FIRMWARE_SUCCESS. */
- uint64_t fitmware_index; /* Firmware index to run. */
+ uint64_t firmware_index; /* Firmware index to run. */
void *kernel_sign_key_blob; /* Key to use when loading kernel.
* Pass this data to LoadKernel() in
* LoadKernelParams.header_sign_key_blob.
@@ -13,43 +13,43 @@
/* Functions provided by PEI to LoadFirmware() */
-/* Get the firmware data for [firmware_index], which is either
+/* Get the firmware body data for [firmware_index], which is either
* 0 (the first firmware image) or 1 (the second firmware image).
*
@@ -13,43 +13,43 @@
* 0 (the first firmware image) or 1 (the second firmware image).
*
- * This function must call LoadFirmwareUpdateDataHash() before
- * returning, to update the secure hash for the firmware image. For
- * best performance, the reader should call this function periodically
+ * This function must call UpdateFirmwareBodyHash() before returning,
+ * to update the secure hash for the firmware image. For best
+ * performance, the reader should call this function periodically
* during the read, so that updating the hash can be pipelined with
* the read. If the reader cannot update the hash during the read
« no previous file with comments | « vboot_firmware/Makefile ('k') | vboot_firmware/lib/load_firmware_fw.c » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698